Package: biobroom
Title: Turn Bioconductor objects into tidy data frames
Version: 1.43.0
Author: Andrew J. Bass, David G. Robinson, Steve Lianoglou, Emily Nelson, John D. Storey, with
    contributions from Laurent Gatto
Maintainer: John D. Storey <jstorey@princeton.edu> and Andrew J. Bass
 <ajbass@emory.edu>
Description: This package contains methods for converting standard objects
    constructed by bioinformatics packages, especially those in Bioconductor,
    and converting them to tidy data. It thus serves as a complement to the broom
    package, and follows the same the tidy, augment, glance division of tidying
    methods. Tidying data makes it easy to recombine, reshape and visualize
    bioinformatics analyses.
biocViews: MultipleComparison, DifferentialExpression, Regression,
        GeneExpression, Proteomics, DataImport
Depends: R (>= 3.0.0), broom
License: LGPL
LazyData: true
Imports: dplyr, tidyr, Biobase
Suggests: limma, DESeq2, airway, ggplot2, plyr, GenomicRanges,
        testthat, magrittr, edgeR, qvalue, knitr, data.table, MSnbase,
        rmarkdown, SummarizedExperiment
VignetteBuilder: knitr
URL: https://github.com/StoreyLab/biobroom
BugReports: https://github.com/StoreyLab/biobroom/issues
RoxygenNote: 5.0.1
git_url: https://git.bioconductor.org/packages/biobroom
git_branch: devel
git_last_commit: 825b1c8
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-30
NeedsCompilation: no
Packaged: 2025-10-30 20:14:45 UTC; biocbuild
