# Generated by roxygen2: do not edit by hand

S3method(augment,DGEList)
S3method(augment,MArrayLM)
S3method(augment,deSet)
S3method(augment,list)
S3method(augment,qvalue)
S3method(glance,DGEExact)
S3method(glance,GRanges)
S3method(glance,GRangesList)
S3method(glance,MArrayLM)
S3method(glance,deSet)
S3method(glance,list)
S3method(glance,qvalue)
S3method(tidy,DESeqDataSet)
S3method(tidy,DESeqResults)
S3method(tidy,DGEExact)
S3method(tidy,DGEList)
S3method(tidy,EList)
S3method(tidy,ExpressionSet)
S3method(tidy,GRanges)
S3method(tidy,GRangesList)
S3method(tidy,MAList)
S3method(tidy,MArrayLM)
S3method(tidy,MSnSet)
S3method(tidy,RangedSummarizedExperiment)
S3method(tidy,deSet)
S3method(tidy,list)
S3method(tidy,qvalue)
export(augment.DGEList)
export(augment.MArrayLM)
export(augment.deSet)
export(augment.qvalue)
export(augment_sva)
export(glance.DGEExact)
export(glance.GRanges)
export(glance.GRangesList)
export(glance.MArrayLM)
export(glance.deSet)
export(glance.qvalue)
export(glance_sva)
export(tidy.DESeqDataSet)
export(tidy.DESeqResults)
export(tidy.DGEExact)
export(tidy.DGEList)
export(tidy.EList)
export(tidy.ExpressionSet)
export(tidy.GRanges)
export(tidy.GRangesList)
export(tidy.MAList)
export(tidy.MArrayLM)
export(tidy.MSnSet)
export(tidy.RangedSummarizedExperiment)
export(tidy.deSet)
export(tidy.qvalue)
export(tidy_sva)
import(broom)
import(dplyr)
importFrom(Biobase,ExpressionSet)
importFrom(Biobase,assayDataElement)
importFrom(Biobase,assayDataElementNames)
importFrom(Biobase,exprs)
importFrom(tidyr,gather)
importFrom(tidyr,spread)
